@@ -60,7 +60,7 @@ def command(commandString: str,
 def get(isPollinationModel: Optional[bool] = False, 
     syncToken: Optional[str] = "",
     key : str = None,
-    platform: str = 'Rhino') -> str:
+    platform: str = 'rhino') -> str:
     """Create a new instance of "button.get".
 
     Parameters
@@ -76,7 +76,7 @@ def get(isPollinationModel: Optional[bool] = False,
         be re-mounted in the Streamlit frontend and lose its current state.
     platform: str
         A key that uniquely identifies the host software. 
-        Supported values: Rhino, Sketchup. Default value is Rhino.
+        Supported values: rhino, sketchup. Default value is rhino.
     Returns
     -------
     string
@@ -95,7 +95,7 @@ def send(action: str,
     uniqueId: str, 
     options: Optional[dict] = {},
     key: str = None,
-    platform: str = 'Rhino') -> str:
+    platform: str = 'rhino') -> str:
     """Create a new instance of "button.send".
 
     Parameters
@@ -129,7 +129,7 @@ def send(action: str,
     
     platform: str
         A key that uniquely identifies the host software. 
-        Supported values: Rhino, Sketchup. Default value is Rhino.
+        Supported values: rhino, sketchup. Default value is rhino.
 
     Returns
     -------
@@ -195,7 +195,7 @@ if not _RELEASE:
 
     host_software = st.selectbox(
      "Host software?",
-     ("Rhino", "Sketchup"))
+     ("rhino", "sketchup"))
 
     print(host_software)
     st.subheader("Pollination, Get/Send Pollination Model Button")
@@ -205,7 +205,7 @@ if not _RELEASE:
     if model:
         json_model = json.loads(model)
         st.write(json_model)
-    if model and host_software == "Rhino":
+    if model and host_software == "rhino":
         command_model = send("BakePollinationModel",
             json_model, "my-secret-key", key="secret-key-3")
 
