@@ -73,9 +73,9 @@ def run_model_viewer(value, key):
 
 # get the platform from the query uri
 query = st.experimental_get_query_params()
-platform = query['__platform__'][0] if '__platform__' in query else 'web'
+platform = special.get_host()
 
-if platform == 'Rhino':
+if platform == 'rhino':
     # special controls
     st.subheader('Pollination Token for Sync')
     po_token = special.sync(key="my-po-sync")
@@ -98,7 +98,7 @@ if platform == 'Rhino':
         dict_data = run_viewer(geometry,
         key="my-super-viewer-2")
 
-if platform == 'Sketchup':
+if platform == 'sketchup':
     # special controls
     st.subheader('Pollination Token for Sync')
     po_token = special.sync(key="my-po-sync")
